@@ -17,24 +17,29 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GSPELL_H__
-#define __GSPELL_H__
+#ifndef GSPELL_H
+#define GSPELL_H
 
-#define __GSPELL_H_INSIDE__
+#define GSPELL_H_INSIDE
 
 #include <gspell/gspell-checker.h>
 #include <gspell/gspell-checker-dialog.h>
-#include <gspell/gspell-inline-checker-text.h>
+#include <gspell/gspell-entry.h>
+#include <gspell/gspell-entry-buffer.h>
 #include <gspell/gspell-language.h>
 #include <gspell/gspell-language-chooser.h>
 #include <gspell/gspell-language-chooser-button.h>
 #include <gspell/gspell-language-chooser-dialog.h>
 #include <gspell/gspell-navigator.h>
-#include <gspell/gspell-navigator-text.h>
+#include <gspell/gspell-navigator-text-view.h>
 #include <gspell/gspell-text-buffer.h>
+#include <gspell/gspell-text-view.h>
 
-#undef __GSPELL_H_INSIDE__
+#include <gspell/gspell-enum-types.h>
+#include <gspell/gspell-version.h>
 
-#endif /* __GSPELL_H__ */
+#undef GSPELL_H_INSIDE
+
+#endif /* GSPELL_H */
 
 /* ex:set ts=8 noet: */
